==> spip_4.0.4.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Enmeti „À“',
	'barre_adresse' => 'Adreso',
	'barre_aide' => 'Uzu tipografiajn fulmkomandojn por riĉigi vian enpaĝigon',
	'barre_alignerdroite' => '[/Dekstrigas/] la alineon',
	'barre_ancres' => 'Mastrumado de la ankroj',
	'barre_barre' => 'Trastreki la tekston',
	'barre_bulle' => 'Ŝpruchelpilo',
	'barre_c_cedille_maj' => 'Enmeti „Ç“',
	'barre_cadre' => 'Meti en &lt;cadre&gt;tekstan lokon&lt;/cadre&gt;',
	'barre_caracteres' => 'Specialaj signoj',
	'barre_centrer' => '[|Centrigi|] la alineon',
	'barre_chercher' => 'Serĉi, anstataŭigi',
	'barre_clean' => 'Purigi la kodon el ĉiuj HTML-markoj',
	'barre_code' => 'Enmeti &lt;code&gt;programkodo&lt;/code&gt;',
	'barre_desindenter' => 'Forigi krommarĝenon de listo',
	'barre_e_accent_aigu' => 'Enmeti „É“',
	'barre_e_accent_grave' => 'Enmeti „È“',
	'barre_ea' => 'Enmeti „æ“',
	'barre_ea_maj' => 'Enmeti „Æ“',
	'barre_encadrer' => '[(Enkadrigi)] la alineon',
	'barre_eo' => 'Enmeti „œ“',
	'barre_eo_maj' => 'Enmeti „Œ“',
	'barre_euro' => 'Enmeti „€“',
	'barre_exposant' => 'Meti la tekston en &lt;sup&gt;supra indico&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Specialaj aranĝoj',
	'barre_galerie' => 'Malfermi la galerion',
	'barre_gestion_anc_bulle' => 'Ankra ŝpruchelpilo',
	'barre_gestion_anc_caption' => 'Mastrumado de la ankroj',
	'barre_gestion_anc_cible' => 'Cela ankro',
	'barre_gestion_anc_inserer' => 'Ŝanĝi en ankron',
	'barre_gestion_anc_nom' => 'Ankronomo',
	'barre_gestion_anc_pointer' => 'Direkti al ankro',
	'barre_gestion_caption' => 'Apudskribo kaj resumo',
	'barre_gestion_colonne' => 'Nombro kolumnoj',
	'barre_gestion_cr_casse' => 'Uskleca kongruo',
	'barre_gestion_cr_changercasse' => 'Ŝanĝi usklecon',
	'barre_gestion_cr_changercassemajuscules' => 'Majuskligi',
	'barre_gestion_cr_changercasseminuscules' => 'Minuskligi',
	'barre_gestion_cr_chercher' => 'Serĉi',
	'barre_gestion_cr_entier' => 'Kompleta vorto',
	'barre_gestion_cr_remplacer' => 'Anstataŭigi',
	'barre_gestion_cr_tout' => 'Ĉion anstataŭigi',
	'barre_gestion_entete' => 'Kapo',
	'barre_gestion_ligne' => 'Nombro linioj',
	'barre_gestion_taille' => 'Fiksa dimensio',
	'barre_glossaire' => 'Elemento de la [?glosaro] (Vikipedio)',
	'barre_gras' => '{{Grasigi}}',
	'barre_guillemets' => 'Ĉirkaŭigi per « citiloj »',
	'barre_guillemets_simples' => 'Ĉirkaŭigi per “duarangaj citiloj”',
	'barre_indenter' => 'Krei krommarĝenon por listo',
	'barre_inserer_cadre' => 'Enmeti kodon',
	'barre_inserer_caracteres' => 'Enmeti specifajn signojn',
	'barre_inserer_code' => 'Enmeti programkodon',
	'barre_intertitre' => '{{{Intertitoligi}}}',
	'barre_italic' => '{Kursivigi}',
	'barre_langue' => 'Mallongigita lingvo',
	'barre_lien' => 'Transformi en [ligilon->http://...]',
	'barre_lien_externe' => 'Ekstera ligilo',
	'barre_lien_input' => 'Bonvolu indiki la adreson de via ligilo. Vi povas enmeti retadreson sub la formo de http://www.miaretejo.com, retpoŝtadreso, aŭ simple enmeti la numeron de tiureteja artikolo.',
	'barre_liste_ol' => 'Listigi numere',
	'barre_liste_ul' => 'Listigi',
	'barre_lorem_ipsum' => 'Enmeti pseŭdo-alineo',
	'barre_lorem_ipsum_3' => 'Enmeti tri pseŭdo-alineoj',
	'barre_miseenevidence' => 'Emfazi [*la tekston*]',
	'barre_note' => '[[Piednotigi]]',
	'barre_paragraphe' => 'Krei alineon',
	'barre_petitescapitales' => 'Meti la tekston en &lt;sc&gt;majuskleto&lt;/sc&gt;',
	'barre_poesie' => 'Prezenti kiel &lt;poesie&gt;poeziaĵon&lt;/poesie&gt;',
	'barre_preview' => 'Antaŭrigarda reĝimo ',
	'barre_quote' => '<quote>Citi mesaĝon</quote>',
	'barre_stats' => 'Montri teksto-statistikojn',
	'barre_tableau' => 'Enmeti/modifi (elekti ĝin unue) tabelon',

	// C
	'config_info_enregistree' => 'Agordo registrita',

	// E
	'editer' => 'Modifi',
	'explication_barre_outils_public' => 'Javascript- kaj CSS-skriptoj de la ilobretoj (kromprogramo Plumingo) uziĝas en la publika spaco kaj ebligas uzi tiujn bretojn kun la forum-formularoj, la publikaj krajonoj aŭ aliaj kromprogramoj, se ilia agordo tion permesas.',
	'explication_barre_outils_public_2' => 'Vi povas elekti ne ŝargi tiujn skriptojn por malpezigi la publikajn paĝon. De nun, kia ajn agordo de la forumoj, krajonoj aŭ kromprogromoj estas, neniu ilobreto de la Plumingo estos ĉe la publika spaco.',

	// I
	'info_barre_outils_public' => 'Publika ilobreto',
	'info_porte_plume_titre' => 'Agordi la ilobretojn',

	// L
	'label_barre_outils_public_non' => 'Ne enmeti la ilobretajn skriptojn en la publikan spacon',
	'label_barre_outils_public_oui' => 'Enmeti la ilobretajn skriptojn en la publikan spacon',

	// V
	'voir' => 'Vidi'
);

==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/porte_plume/lang/barreoutils_eo.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/barreoutils?lang_cible=eo
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'barre_a_accent_grave' => 'Enmeti „À“',
	'barre_adresse' => 'Adreso',
	'barre_aide' => 'Uzu tipografiajn fulmkomandojn por riĉigi vian enpaĝigon',
	'barre_alignerdroite' => '[/Dekstrigas/] la alineon',
	'barre_ancres' => 'Mastrumado de la ankroj',
	'barre_barre' => 'Trastreki la tekston',
	'barre_bulle' => 'Ŝpruchelpilo',
	'barre_c_cedille_maj' => 'Enmeti „Ç“',
	'barre_cadre' => 'Meti en &lt;cadre&gt;tekstan lokon&lt;/cadre&gt;',
	'barre_caracteres' => 'Specialaj signoj',
	'barre_centrer' => '[|Centrigi|] la alineon',
	'barre_chercher' => 'Serĉi, anstataŭigi',
	'barre_clean' => 'Purigi la kodon el ĉiuj HTML-markoj',
	'barre_code' => 'Enmeti &lt;code&gt;programkodo&lt;/code&gt;',
	'barre_desindenter' => 'Forigi krommarĝenon de listo',
	'barre_e_accent_aigu' => 'Enmeti „É“',
	'barre_e_accent_grave' => 'Enmeti „È“',
	'barre_ea' => 'Enmeti „æ“',
	'barre_ea_maj' => 'Enmeti „Æ“',
	'barre_encadrer' => '[(Enkadrigi)] la alineon',
	'barre_eo' => 'Enmeti „œ“',
	'barre_eo_maj' => 'Enmeti „Œ“',
	'barre_euro' => 'Enmeti „€“',
	'barre_exposant' => 'Meti la tekston en &lt;sup&gt;supra indico&lt;/sup&gt;',
	'barre_formatages_speciaux' => 'Specialaj aranĝoj',
	'barre_galerie' => 'Malfermi la galerion',
	'barre_gestion_anc_bulle' => 'Ankra ŝpruchelpilo',
	'barre_gestion_anc_caption' => 'Mastrumado de la ankroj',
	'barre_gestion_anc_cible' => 'Cela ankro',
	'barre_gestion_anc_inserer' => 'Ŝanĝi en ankron',
	'barre_gestion_anc_nom' => 'Ankronomo',
	'barre_gestion_anc_pointer' => 'Direkti al ankro',
	'barre_gestion_caption' => 'Apudskribo kaj resumo',
	'barre_gestion_colonne' => 'Nombro kolumnoj',
	'barre_gestion_cr_casse' => 'Uskleca kongruo',
	'barre_gestion_cr_changercasse' => 'Ŝanĝi usklecon',
	'barre_gestion_cr_changercassemajuscules' => 'Majuskligi',
	'barre_gestion_cr_changercasseminuscules' => 'Minuskligi',
	'barre_gestion_cr_chercher' => 'Serĉi',
	'barre_gestion_cr_entier' => 'Kompleta vorto',
	'barre_gestion_cr_remplacer' => 'Anstataŭigi',
	'barre_gestion_cr_tout' => 'Ĉion anstataŭigi',
	'barre_gestion_entete' => 'Kapo',
	'barre_gestion_ligne' => 'Nombro linioj',
	'barre_gestion_taille' => 'Fiksa dimensio',
	'barre_glossaire' => 'Elemento de la [?glosaro] (Vikipedio)',
	'barre_gras' => '{{Grasigi}}',
	'barre_guillemets' => 'Ĉirkaŭigi per « citiloj »',
	'barre_guillemets_simples' => 'Ĉirkaŭigi per “duarangaj citiloj”',
	'barre_indenter' => 'Krei krommarĝenon por listo',
	'barre_inserer_cadre' => 'Enmeti kodon', # MODIF
	'barre_inserer_caracteres' => 'Enmeti specifajn signojn',
	'barre_inserer_code' => 'Enmeti programkodon', # MODIF
	'barre_intertitre' => '{{{Intertitoligi}}}',
	'barre_italic' => '{Kursivigi}',
	'barre_langue' => 'Mallongigita lingvo',
	'barre_lien' => 'Transformi en [ligilon->http://...]',
	'barre_lien_externe' => 'Ekstera ligilo',
	'barre_lien_input' => 'Bonvolu indiki la adreson de via ligilo. Vi povas enmeti retadreson sub la formo de http://www.miaretejo.com, retpoŝtadreso, aŭ simple enmeti la numeron de tiureteja artikolo.',
	'barre_liste_ol' => 'Listigi numere',
	'barre_liste_ul' => 'Listigi',
	'barre_lorem_ipsum' => 'Enmeti pseŭdo-alineo',
	'barre_lorem_ipsum_3' => 'Enmeti tri pseŭdo-alineoj',
	'barre_miseenevidence' => 'Emfazi [*la tekston*]',
	'barre_note' => '[[Piednotigi]]',
	'barre_paragraphe' => 'Krei alineon',
	'barre_petitescapitales' => 'Meti la tekston en &lt;sc&gt;majuskleto&lt;/sc&gt;',
	'barre_poesie' => 'Prezenti kiel &lt;poesie&gt;poeziaĵon&lt;/poesie&gt;',
	'barre_preview' => 'Antaŭrigarda reĝimo ',
	'barre_quote' => '<quote>Citi mesaĝon</quote>',
	'barre_stats' => 'Montri teksto-statistikojn',
	'barre_tableau' => 'Enmeti/modifi (elekti ĝin unue) tabelon',

	// C
	'config_info_enregistree' => 'Agordo registrita',

	// E
	'editer' => 'Modifi',
	'explication_barre_outils_public' => 'Javascript- kaj CSS-skriptoj de la ilobretoj (kromprogramo Plumingo) uziĝas en la publika spaco kaj ebligas uzi tiujn bretojn kun la forum-formularoj, la publikaj krajonoj aŭ aliaj kromprogramoj, se ilia agordo tion permesas.',
	'explication_barre_outils_public_2' => 'Vi povas elekti ne ŝargi tiujn skriptojn por malpezigi la publikajn paĝon. De nun, kia ajn agordo de la forumoj, krajonoj aŭ kromprogromoj estas, neniu ilobreto de la Plumingo estos ĉe la publika spaco.',

	// I
	'info_barre_outils_public' => 'Publika ilobreto',
	'info_porte_plume_titre' => 'Agordi la ilobretojn',

	// L
	'label_barre_outils_public_non' => 'Ne enmeti la ilobretajn skriptojn en la publikan spacon',
	'label_barre_outils_public_oui' => 'Enmeti la ilobretajn skriptojn en la publikan spacon',

	// V
	'voir' => 'Vidi'
);
